import { Injectable } from '@angular/core';
import { Http,RequestOptions,Headers,URLSearchParams } from '@angular/http';
import { LoadingController,Loading,AlertController } from 'ionic-angular';
import 'rxjs/add/operator/map';

/*
  Generated class for the OrderService provider.

  See https://angular.io/docs/ts/latest/guide/dependency-injection.html
  for more info on providers and Angular 2 DI.
*/
@Injectable()
export class OrderService {

  public Language:string = "ES";
  public UserName:string = "";
  public Password:string = "";
  public Device:string = "";
  //private ServicePath:string = "http://localhost:9001/api/";
  //public ServiceImagePath:string = "http://localhost:9001/imageart/";
  
  //private ServicePath:string = "http://donpin.com:8090/api/";
  //public ServiceImagePath:string = "http://donpin.com:8090/imageart/";
  //private ServicePath:string = "http://reportman.ddns.net:8090/api/";
  //public ServiceImagePath:string = "http://reportman.ddns.net:8090/imageart/";

  private ServicePath:string = "http://213.98.62.116:1665/api/";
  public ServiceImagePath:string = "http://213.98.62.116:1665/imageart/";


  private ServiceLoginPath:string;
  private ServiceProductPath:string;
  private ServiceOrdersPath:string;
  private ServiceUnRegisterDevicePath:string;
  private ServiceOrderDetailPath:string;
  private options:RequestOptions;
  private loader:Loading;
  private ServiceOrderCMSPath:string;

  constructor(public http: Http,public loadingCtrl: LoadingController,
    public alertCtrl: AlertController) {
    console.log('Hello OrderService Provider');
    this.options = new RequestOptions({headers: new Headers({'Content-Type': 'application/json'})});
    //this.options.headers.append('Access-Control-Allow-Origin', '*');
    this.options.headers.append('Access-Control-Allow-Origin', 'http://localhost:8100');
    this.ServiceLoginPath = this.ServicePath+"login";
    this.ServiceOrdersPath = this.ServicePath+"orders";
    this.ServiceOrderDetailPath = this.ServicePath+"orderdetail";
    this.ServiceUnRegisterDevicePath = this.ServicePath+"unregister";
    this.ServiceProductPath = this.ServicePath+"product";
    this.ServiceOrderCMSPath = this.ServicePath+"cms";
    this.LoadUserData();
  }
  public LoadUserData()
  {
    var storedusername = localStorage.getItem('username');
    var storedpassword = localStorage.getItem('pasword');
    var storeddevice = localStorage.getItem('device');
    if (typeof storedusername === "string")
    {
      this.UserName = storedusername;
    }
    if (typeof storedpassword === "string")
    {
      this.Password = storedpassword;
    }
    if (typeof storeddevice === "string")
    {
      this.Device = storeddevice;
    }
  }
  public Exit()
  {
    // Remove login data
    this.SaveUser("","",this.Device);
  }
  public Login(user:string,password:string,progress:Boolean) 
  {
    return new Promise(resolve => {
    // We're using Angular HTTP provider to request the data,
    // then on the response, it'll map the JSON data to a parsed JS object.
    // Next, we process the data and resolve the promise with the new data.
    let params: URLSearchParams = new URLSearchParams();
    //let longpassword:string = sha1(password);
    params.set("username", user);
    params.set("password", password);
    params.set("language", this.Language);
    params.set("device", this.Device);
    this.options.search = params;
    if (progress)    
      this.ShowProgress()
    this.http.get(this.ServiceLoginPath,this.options)
      .map(res => res.json())
      .subscribe(data => {
        // we've got back the raw data, now generate the core schedule data
        // and save the data for later reference
        if (progress)
          this.HideProgress();
        resolve(data);
      },err => {
          var error_message:string = err.toString();
          error_message = error_message.replace(password,"*************"); 
          console.log('Error http:'+error_message);
          if (progress)
            this.HideProgress();
             let alert = this.alertCtrl.create({
            title: 'Error',
            subTitle: error_message,
            buttons: ['OK']
            });
          alert.present();        
        }
      );
    });
  }
  public GetOrders(sender:any,count:number,skip:number,order_id:number,progress:Boolean) 
  {
    return new Promise(resolve => {
    // We're using Angular HTTP provider to request the data,
    // then on the response, it'll map the JSON data to a parsed JS object.
    // Next, we process the data and resolve the promise with the new data.
    let params: URLSearchParams = new URLSearchParams();
    //let longpassword:string = sha1(password);
    params.set("username", this.UserName);
    params.set("password", this.Password);
    params.set("language", this.Language);
    params.set("count", count.toString());
    params.set("skip", skip.toString());
    params.set("order_id", order_id.toString());
    //params.set("days", "600");
    this.options.search = params;    
    if (progress)
      this.ShowProgress()
    this.http.get(this.ServiceOrdersPath,this.options)
      .map(res => res.json())
      .subscribe(data => {
        // we've got back the raw data, now generate the core schedule data
        // and save the data for later reference
        data["sender"] = sender;
        if (progress)
         this.HideProgress();
        resolve(data);
      },err => {
          console.log('Error http:'+err);
          if (progress)
            this.HideProgress();
             let alert = this.alertCtrl.create({
            title: 'Error',
            subTitle: err,
            buttons: ['OK']
            });
          alert.present();        
        }
      );
    });
  }
  public GetOrder(sender:any,orderNumber:number) 
  {
    return new Promise(resolve => {
    // We're using Angular HTTP provider to request the data,
    // then on the response, it'll map the JSON data to a parsed JS object.
    // Next, we process the data and resolve the promise with the new data.
    let params: URLSearchParams = new URLSearchParams();
    //let longpassword:string = sha1(password);
    params.set("username", this.UserName);
    params.set("password", this.Password);
    params.set("language", this.Language);
    params.set("order", orderNumber.toString());
    this.options.search = params;    
    this.ShowProgress()
    this.http.get(this.ServiceOrderDetailPath,this.options)
      .map(res => res.json())
      .subscribe(data => {
        // we've got back the raw data, now generate the core schedule data
        // and save the data for later reference
        data["sender"] = sender;
        this.HideProgress();
        resolve(data);
      },err => {
          console.log('Error http:'+err);
          this.HideProgress();
             let alert = this.alertCtrl.create({
            title: 'Error',
            subTitle: err,
            buttons: ['OK']
            });
          alert.present();        
        }
      );
    });
  }
  public GetCMS(sender:any) 
  {
    return new Promise(resolve => {
    // We're using Angular HTTP provider to request the data,
    // then on the response, it'll map the JSON data to a parsed JS object.
    // Next, we process the data and resolve the promise with the new data.
    let params: URLSearchParams = new URLSearchParams();
    //let longpassword:string = sha1(password);
    params.set("username", this.UserName);
    params.set("password", this.Password);
    params.set("language", this.Language);
    params.set("cms_code", "1");
    this.options.search = params;    
    this.http.get(this.ServiceOrderCMSPath,this.options)
      .map(res => res.json())
      .subscribe(data => {
        // we've got back the raw data, now generate the core schedule data
        // and save the data for later reference
        data["sender"] = sender;
        resolve(data);
      },err => {
          console.log('Error http:'+err);
          /*   let alert = this.alertCtrl.create({
            title: 'Error',
            subTitle: err,
            buttons: ['OK']
            });
          alert.present();*/        
        }
      );
    });
  }
  public GetProduct(sender:any,productNumber:number,productBarcode:string) 
  {
    return new Promise(resolve => {
    // We're using Angular HTTP provider to request the data,
    // then on the response, it'll map the JSON data to a parsed JS object.
    // Next, we process the data and resolve the promise with the new data.
    let params: URLSearchParams = new URLSearchParams();
    //let longpassword:string = sha1(password);
    params.set("username", this.UserName);
    params.set("password", this.Password);
    params.set("language", this.Language);
    params.set("product_id", productNumber.toString());
    params.set("product_barcode", productBarcode.toString());
    this.options.search = params;    
    this.ShowProgress()
    this.http.get(this.ServiceProductPath,this.options)
      .map(res => res.json())
      .subscribe(data => {
        // we've got back the raw data, now generate the core schedule data
        // and save the data for later reference
        data["sender"] = sender;
        this.HideProgress();
        resolve(data);
      },err => {
          console.log('Error http:'+err);
          this.HideProgress();
             let alert = this.alertCtrl.create({
            title: 'Error',
            subTitle: err,
            buttons: ['OK']
            });
          alert.present();        
        }
      );
    });
  }
  public SaveUser(user:string,password:string,device:string)
  {
    localStorage.setItem('username',user);
    localStorage.setItem('pasword',password);
    localStorage.setItem('device',device);
    this.UserName = user;
    this.Password = password;
    this.Device = device;
  }
  ShowProgress()
  {
    this.loader = this.loadingCtrl.create({
    content: "",
    //duration: 3000
    });
    this.loader.present();
  }
  HideProgress()
  {
        this.loader.dismiss();
  }
   
  private days:Array<{1: string, 2: string, 3: string,4:string,5:string,6:string,7:string}> = 
  [{1:"Lunes",2:"Martes",3:"Miércoles",4:"Jueves",
     5:"Viernes",6:"Sábado",7:"Domingo"},
     {1:"星期一",2:"星期二",3:"星期三",4:"星期四",
     5:"星期五",6:"星期六",7:"星期天"}
     ]  
  public TranslateDay(day:number):string
  {
     var translateresult:string = "";
      if (this.Language === "ES")
      {
        translateresult = this.days[0][day.toString()];
      }
      else
        translateresult =  this.days[1][day.toString()];
     return translateresult;
  }
}
